package remotectrl;
/******************************************************************
*
*	CyberUPnP for Java
*
*	Copyright (C) Satoshi Konno 2002
*
*	File : ClockDevice.java
*
******************************************************************/

import org.cybergarage.upnp.*;
import org.cybergarage.upnp.ssdp.*;
import org.cybergarage.upnp.device.*;
import org.cybergarage.upnp.event.*;

public class RemoteCtrl extends ControlPoint implements NotifyListener, EventListener, SearchResponseListener
{
	private final static String TV_DEVICE_TYPE = "urn:schemas-upnp-org:device:tv:1";
	private final static String TV_SERVICE_TYPE = "urn:schemas-upnp-org:service:power:1";

	private final static String LIGHT_DEVICE_TYPE = "urn:schemas-upnp-org:device:light:1";
	private final static String LIGHT_SERVICE_TYPE = "urn:schemas-upnp-org:service:power:1";

	private final static String AIRCON_DEVICE_TYPE = "urn:schemas-upnp-org:device:aircon:1";
	private final static String AIRCON_SERVICE_TYPE = "urn:schemas-upnp-org:service:power:1";

	private final static String WASHER_DEVICE_TYPE = "urn:schemas-upnp-org:device:washer:1";
	private final static String WASHER_SERVICE_TYPE = "urn:schemas-upnp-org:service:state:1";

	public RemoteCtrl()
	{
		addNotifyListener(this);
		addSearchResponseListener(this);
		addEventListener(this);
		
	//	search(WASHER_DEVICE_TYPE);
	}
	
	////////////////////////////////////////////////
	//	Listener
	////////////////////////////////////////////////
	
	public void deviceNotifyReceived(SSDPPacket packet)
	{
               System.out.println(packet.toString());
	       if (packet.isDiscover() == true) {
		       String st = packet.getST();
		       System.out.println("ssdp:discover : ST = " + st); 
		}
	        else if (packet.isAlive() == true) {
	              String usn = packet.getUSN();
	               String nt = packet.getNT();
	               String url = packet.getLocation();
	               System.out.println("ssdp:alive : uuid = " + usn + ", NT = " + nt + ", location = " + url); 
	          }
	       else if (packet.isByeBye() == true) {
	                String usn = packet.getUSN();
	          String nt = packet.getNT();
	         System.out.println("ssdp:byebye : uuid = " + usn + ", NT = " + nt); 
	     }         
			
	}
	
	public void deviceSearchResponseReceived(SSDPPacket packet)
	{
               String uuid = packet.getUSN();
            String st = packet.getST();
           String url = packet.getLocation();
          System.out.println("device search res : uuid = " + uuid + ", ST = " + st + ", location = " + url);
	}
	
	public void eventNotifyReceived(String uuid, long seq, String name, String value)
	{
		System.out.println("event notify : uuid = " + uuid + ", seq = " + seq + ", name = " + name + ", value =" + value);
			 
	}

	////////////////////////////////////////////////
	//	Power
	////////////////////////////////////////////////
	
	public void powerOn(String deviceType)
	{
		Device dev = getDevice(deviceType);
		if (dev == null)
			return;
		Action getPowerAct = dev.getAction("GetPower");
		if (getPowerAct.postControlAction() == false)
			return;
			
		ArgumentList outArgList = getPowerAct.getOutputArgumentList();
		String powerState = outArgList.getArgument(0).getValue();
		String newPowerState = (powerState.compareTo("1") == 0) ? "0" : "1";
		
		Action setPowerAct = dev.getAction("SetPower");
		setPowerAct.setArgumentValue("Power", newPowerState);
		setPowerAct.postControlAction();
	}

	////////////////////////////////////////////////
	//	TV
	////////////////////////////////////////////////
	
	public void tvPowerOn()
	{
		//powerOn(TV_DEVICE_TYPE);
		search(WASHER_DEVICE_TYPE);

		System.out.println("AFTER SEARCH ");
	}

	////////////////////////////////////////////////
	//	Light
	////////////////////////////////////////////////
	
	public void lightPowerOn()
	{
	//	powerOn(LIGHT_DEVICE_TYPE);
		search(TV_DEVICE_TYPE);
		System.out.println("AFTER SEARCH ");
	}

	////////////////////////////////////////////////
	//	Aircon
	////////////////////////////////////////////////
	
	public void airconPowerOn()
	{
		powerOn(AIRCON_DEVICE_TYPE);
	}

	public void airconChangeTemp(String tempOff)
	{

		Device dev = getDevice(TV_DEVICE_TYPE);
		System.out.println("device washer="+dev);
		if (dev == null)
			return;
		System.out.println("Before calling action1");
		Action setTempAct = dev.getAction("SetPower");
		System.out.println("calling action2: "+setTempAct+" +1");
		setTempAct.setArgumentValue("state", "+1");
		System.out.println("Before calling action3");
		setTempAct.postControlAction();
		System.out.println("Before calling action4");
		/*
		Device dev = getDevice(AIRCON_DEVICE_TYPE);
		if (dev == null)
			return;
		Action setTempAct = dev.getAction("SetTemp");
		setTempAct.setArgumentValue("Temp", tempOff);
		setTempAct.postControlAction();
		*/
	}

	public void airconTempUp()
	{
		//airconChangeTemp("+1");
		search("urn:schemas-upnp-org:device:HelloWorldService:1");
	}
 
	public void airconTempDown()
	{
		//airconChangeTemp("-1");
		Device dev = getDevice("urn:schemas-upnp-org:device:HelloWorldService:1");
		System.out.println("device HelloWorldService="+dev);
		if (dev == null)
			return;
		System.out.println("Before calling action1");
		Action setTempAct = dev.getAction("SetState");
		System.out.println("calling action2: "+setTempAct+" 1 ");
		setTempAct.setArgumentValue("state",  "1");
		System.out.println("Before calling action3");
		setTempAct.postControlAction();
		System.out.println("Before calling action4");
	}

	////////////////////////////////////////////////
	//	Aircon
	////////////////////////////////////////////////
	
	public void setWasherState(String value)
	{

		Device dev = getDevice(WASHER_DEVICE_TYPE);
		System.out.println("device washer="+dev);
		if (dev == null)
			return;
		System.out.println("Before calling action1");
		Action setTempAct = dev.getAction("SetState");
		System.out.println("calling action2: "+setTempAct+" "+value);
		setTempAct.setArgumentValue("state", value);
		System.out.println("Before calling action3");
		setTempAct.postControlAction();
		System.out.println("Before calling action4");
	}

	public void washerStart()
	{
		setWasherState("1");
	}

	public void washerStop()
	{
		setWasherState("0");
	}

}

