/******************************************************************
*
*	CyberUPnP for Java
*
*	Copyright (C) Satoshi Konno 2002-2003
*
*	File: SSDPSearchResponseSocketList.java
*
*	Revision;
*
*	05/08/03
*		- first revision.
*	05/28/03
*		- Added post() to send a SSDPSearchRequest.
*
******************************************************************/

package org.cybergarage.upnp.ssdp;

import java.util.*;

import org.cybergarage.net.*;

import org.cybergarage.upnp.*;

public class SSDPSearchResponseSocketList extends Vector 
{
	////////////////////////////////////////////////
	//	Constructor
	////////////////////////////////////////////////
	
	public SSDPSearchResponseSocketList() 
	{
	}

	////////////////////////////////////////////////
	//	ControlPoint
	////////////////////////////////////////////////

	public void setControlPoint(ControlPoint ctrlPoint)
	{
		int nSockets = size();
		for (int n=0; n<nSockets; n++) {
			SSDPSearchResponseSocket sock = getSSDPSearchResponseSocket(n);
			sock.setControlPoint(ctrlPoint);
		}
	}

	////////////////////////////////////////////////
	//	get
	////////////////////////////////////////////////
	
	public SSDPSearchResponseSocket getSSDPSearchResponseSocket(int n)
	{
		return (SSDPSearchResponseSocket)get(n);
	}
	
	////////////////////////////////////////////////
	//	Methods
	////////////////////////////////////////////////
	
	public boolean open(int port)
	{
 System.out.println("SSDPSearchResponseSocketList.open: "+port);
		try {
			int nHostAddrs = HostInterface.getNHostAddresses();
			for (int n=0; n<nHostAddrs; n++) {
				String bindAddr = HostInterface.getHostAddress(n);
				SSDPSearchResponseSocket socket = new SSDPSearchResponseSocket(bindAddr, port);
				add(socket);
			}
		}
		catch (Exception e) {
			stop();
			close();
			clear();
			return false;
		}
		return true;
	}

	public boolean open() 
	{
		return open(SSDP.PORT);
	}
		
	public void close()
	{
		int nSockets = size();
		for (int n=0; n<nSockets; n++) {
			SSDPSearchResponseSocket sock = getSSDPSearchResponseSocket(n);
			sock.close();
		}
		clear();
	}

	////////////////////////////////////////////////
	//	Methods
	////////////////////////////////////////////////
	
	public void start()
	{
		int nSockets = size();
		for (int n=0; n<nSockets; n++) {
			SSDPSearchResponseSocket sock = getSSDPSearchResponseSocket(n);
			sock.start();
		}
	}

	public void stop()
	{
		int nSockets = size();
		for (int n=0; n<nSockets; n++) {
			SSDPSearchResponseSocket sock = getSSDPSearchResponseSocket(n);
			sock.stop();
		}
	}

	////////////////////////////////////////////////
	//	Methods
	////////////////////////////////////////////////

	public boolean post(SSDPSearchRequest req)
	{
		boolean ret = true;
		int nSockets = size();

		System.out.println("SSDPSearchResponseSocketList.post1: "+nSockets);
		
		for (int n=0; n<nSockets; n++) {
		System.out.println("SSDPSearchResponseSocketList.post2: "+req.toString());
			SSDPSearchResponseSocket sock = getSSDPSearchResponseSocket(n);
		System.out.println("SSDPSearchResponseSocketList.post3: "+nSockets);
			String bindAddr = sock.getLocalAddress();
		System.out.println("SSDPSearchResponseSocketList.post4: "+nSockets);
			req.setLocalAddress(bindAddr);
		System.out.println("SSDPSearchResponseSocketList.post5: "+nSockets);
			String ssdpAddr = SSDP.ADDRESS;
		System.out.println("SSDPSearchResponseSocketList.post6: "+nSockets);
			if (HostInterface.isIPv6Address(bindAddr) == true) {
				ssdpAddr = SSDP.getIPv6Address();
			//sock.joinGroup(ssdpAddr, SSDP.PORT, bindAddr);
			
		System.out.println("SSDPSearchResponseSocketList.post7: "+nSockets);
			}
			if (sock.post(ssdpAddr, SSDP.PORT, req) == false) {
				ret = false;
			//sock.leaveGroup(ssdpAddr, SSDP.PORT, bindAddr);
		System.out.println("SSDPSearchResponseSocketList.post8: "+nSockets);
			}
		}
		return ret;
	}
	
}

